@@ -257,13 +257,15 @@ extern GPROC genie_matrix_minus;
 extern GPROC genie_matrix_minusab;
 extern GPROC genie_matrix_ne;
 extern GPROC genie_matrix_norm;
+extern GPROC genie_matrix_ols;
 extern GPROC genie_matrix_pca_cv;
 extern GPROC genie_matrix_pca_svd;
 extern GPROC genie_matrix_pca_svd_full;
+extern GPROC genie_matrix_pcr;
 extern GPROC genie_matrix_pinv;
 extern GPROC genie_matrix_pinv_lim;
 extern GPROC genie_matrix_pls1;
-extern GPROC genie_matrix_pls1_lim;
+extern GPROC genie_matrix_pls2;
 extern GPROC genie_matrix_plusab;
 extern GPROC genie_matrix_qr;
 extern GPROC genie_matrix_qr_ls_solve;
@@ -275,6 +277,7 @@ extern GPROC genie_matrix_svd;
 extern GPROC genie_matrix_svd_solve;
 extern GPROC genie_matrix_times_matrix;
 extern GPROC genie_matrix_times_vector;
+extern GPROC genie_matrix_tls;
 extern GPROC genie_matrix_trace;
 extern GPROC genie_matrix_transpose;
 extern GPROC genie_matrix_vcat;
